@@ -16,7 +16,7 @@
 ;; But at least until dec 2015 we didn't need to check for a specific windows flavour.
 (defparameter *autoconf-win32* "false")
 (defparameter *autoconf-windows* "false")
-(defparameter *autoconf-ld-flags* "-Wl,-O1,--sort-common,--as-needed,-z,relro")
+(defparameter *autoconf-ld-flags* "-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now")
 
 ;; This will be T if this was a lisp-only build
 (defparameter *autoconf-lisp-only-build* (eq t '@lisp_only_build@))
